==> am_mod_lbr_0_2.zip: am_module_library/components/lbr/template/barnraiser_01/list.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<form action="index.php?amn=lbr_list" method="post" name="frm" id="id_frm">
<input type="hidden" name="set_id" value="<?php if(isset($page['set_id'])) { echo $page['set_id'];}?>" />

<div class="col_main">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_list'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($revisions)) {
				?>
				<table border="0" cellspacing="2" cellpadding="2" width="100%">
				<?php
				foreach($revisions as $key => $i):
				?>
				<tr>
					<td valign="top">
						<b><?php echo $lang['txt_set'];?></b>: <a href="index.php?amn=lbr_page&amp;set_id=<?php echo $i['set_id'];?>"><?php echo $i['set_title'];?></a><br />
					</td>
					<td valign="top">
						<b><?php echo $lang['txt_page'];?></b>:
						<a href="index.php?amn=lbr_page&amp;page_id=<?php echo $i['page_id'];?>"><?php echo $i['page_title'];?></a><br />
					</td>
				</tr>
				<tr>
					<td valign="top" colspan="2">
						<a href="index.php?amn=lbr_page&amp;revision_id=<?php echo $i['revision_id'];?>"><b><?php echo $this->date->formatDate($i['revision_create_datetime'],1);?></b></a>
						<?php echo $i['revision_body'];?><br />
					</td>
				</tr>
				<tr>
					<td colspan="2">
						<br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				
				<?php
				}
				elseif (isset($pages)) {
				?>
				<table border="0" cellspacing="2" cellpadding="2" width="100%">
				<?php
				foreach($pages as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="index.php?amn=lbr_page&amp;page_id=<?php echo $i['page_id'];?>"><?php echo $i['page_title'];?></a><br />
						<?php echo $i['page_synopsis'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				
				<?php
				}
				elseif (isset($tags)) {
				?>
				<table border="0" cellspacing="2" cellpadding="2" width="100%">
				<?php
				foreach($tags as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="index.php?amn=lbr_page&amp;page_id=<?php echo $i['page_id'];?>"><?php echo $i['page_title'];?></a><br />
						<?php echo $i['page_synopsis'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				}
				elseif (isset($display) && $display == 'intro') {
				?>
					<p>
						<?php echo $lang['txt_search_intro'];?><br />
					</p>
				<?php
				}
				else {
				?>
					<p>
						<?php echo $lang['template_error']['err_no_items'];?><br />
					</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>

<div class="col_side">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_search'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<input type="text" name="search_text" value="<?php if(isset($_POST['search_text'])) { echo $_POST['search_text'];};?>" class="input1" /><br />
				</p>
				
				<p>
					<input type="checkbox" name="local" value="1" checked="checked" /><?php echo $lang['txt_current_only'];?></input><br />
				</p>
				
				<hr />
				
				<p align="right">
					<input type="submit" name="search" class="input_submit" value="<?php echo $lang['sub_search']; ?>" /><br />
				</p>
			</div>
		</div>
	</div>
	
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>
</form>

==> am_mod_lbr_0_4.zip: am_module_library/components/lbr/template/barnraiser_01/list.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of aroundme
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
-->
</style>

<form action="index.php?amn=lbr_list" method="post" name="frm" id="id_frm">
<input type="hidden" name="set_id" value="<?php if(isset($page['set_id'])) { echo $page['set_id'];}?>" />

<div class="col_main">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<?php echo $lang['hdr_list'];?><br />
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($sets)) {
				?>
				<table border="0" cellspacing="0" cellpadding="2" width="100%">
				<?php
				foreach($sets as $key => $i):
				?>
				<tr>
					<td width="32">
						<a href="index.php?amn=lbr_page&amp;set_id=<?php echo $i['set_id'];?>"><img src="get_file.php?file=<?php echo $i['image']['file_md5_name_view'];?>" border="0" alt="<?php echo $i['image']['file_title'];?>" /></a><br />
					</td>
					<td>
						<a href="index.php?amn=lbr_page&amp;set_id=<?php echo $i['set_id'];?>"><b><?php echo $i['set_title'];?></b></a><br />
						<?php echo $i['set_synopsis'];?>
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				}
				elseif (isset($revisions)) {
				?>
				<table border="0" cellspacing="2" cellpadding="2" width="100%">
				<?php
				foreach($revisions as $key => $i):
				?>
				<tr>
					<td valign="top">
						<b><?php echo $lang['txt_set'];?></b>: <a href="index.php?amn=lbr_page&amp;set_id=<?php echo $i['set_id'];?>"><?php echo $i['set_title'];?></a><br />
					</td>
					<td valign="top">
						<b><?php echo $lang['txt_page'];?></b>:
						<a href="index.php?amn=lbr_page&amp;page_id=<?php echo $i['page_id'];?>"><?php echo $i['page_title'];?></a><br />
					</td>
				</tr>
				<tr>
					<td valign="top" colspan="2">
						<a href="index.php?amn=lbr_page&amp;revision_id=<?php echo $i['revision_id'];?>"><b><?php echo $this->date->formatDate($i['revision_create_datetime'],1);?></b></a>
						<?php echo $i['revision_body'];?><br />
					</td>
				</tr>
				<tr>
					<td colspan="2">
						<br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				
				<?php
				}
				elseif (isset($pages)) {
				?>
				<table border="0" cellspacing="2" cellpadding="2" width="100%">
				<?php
				foreach($pages as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="index.php?amn=lbr_page&amp;page_id=<?php echo $i['page_id'];?>"><?php echo $i['page_title'];?></a><br />
						<?php echo $i['page_synopsis'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				
				<?php
				}
				elseif (isset($tags)) {
				?>
				<table border="0" cellspacing="2" cellpadding="2" width="100%">
				<?php
				foreach($tags as $key => $i):
				?>
				<tr>
					<td valign="top">
						<a href="index.php?amn=lbr_page&amp;page_id=<?php echo $i['page_id'];?>"><?php echo $i['page_title'];?></a><br />
						<?php echo $i['page_synopsis'];?><br />
					</td>
				</tr>
				<tr>
					<td>
						<br />
					</td>
				</tr>
				<?php
				endforeach;
				?>
				</table>
				<?php
				}
				elseif (isset($display) && $display == 'intro') {
				?>
					<p>
						<?php echo $lang['txt_search_intro'];?><br />
					</p>
				<?php
				}
				else {
				?>
					<p>
						<?php echo $lang['template_error']['err_no_items'];?><br />
					</p>
				<?php }?>
			</div>
		</div>
	</div>
</div>

<div class="col_side">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<?php echo $lang['hdr_search'];?><br />
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<input type="text" name="search_text" value="<?php if(isset($_POST['search_text'])) { echo $_POST['search_text'];};?>" class="input1" /><br />
				</p>
				
				<p>
					<input type="checkbox" name="local" value="1" checked="checked" /><?php echo $lang['txt_current_only'];?></input><br />
				</p>
				
				<hr />
				
				<p align="right">
					<input type="submit" name="search" class="input_submit" value="<?php echo $lang['sub_search']; ?>" /><br />
				</p>
			</div>
		</div>
	</div>
</div>
</form>
